import 'package:xdja_bridge/gprs_server/protocol/base_protocol/base_request.dart';
import 'package:xml/xml.dart';

const policeNoType = '0';
const idcardType = '1';
const moblieType = '2';
const billType = '3';

/// 警务通 GPRS Server 登录协议
class LoginRequest with BaseRequest{
  /// 警号
  String policeNo;

  ///请求类别
  String reqType = 'login';

  /// 登录认证方式0-警号，1-身份证，2-手机号，3-票据
  String validateType = '3';

  /// 登录所有证件号码，如果使用票据验验证，为票据信息
  String validateValue;

  /// 登录密码，如果是票据验证密码不填
  String validatePass;

  /// 终端程序当前版本
  String currentVersion;

  /// 终端设备类型
  String clientType;
  String cardType = '3';
  String imsi;
  String imei;
  String iccid;
  String pver;


  String buildXml() {
    var builder = XmlBuilder();
    builder.declaration(encoding: 'UTF-8');
    builder.element('Root', nest: () {
      if (policeNo != null && policeNo.isNotEmpty) {
        builder.element('Police', nest: policeNo);
      }
      builder.element('ReqType', nest: reqType);
      builder.element('ValidateType', nest: validateType);
      builder.element('ValidateValue', nest: () {
        builder.cdata(validateValue);
      });
      builder.element('ValidatePass', nest: validatePass);
      builder.element('CurrentVersion', nest: currentVersion);
      builder.element('ClientType', nest: clientType);
      builder.element('IMSI', nest: imsi);
      builder.element('IMEI', nest: imei);
      if (iccid != null && iccid.isNotEmpty) {
        builder.element('ICCID', nest: iccid);
      }
      builder.element('Pver',
          nest: {pver != null && pver.isNotEmpty ? pver : '20140501'});
      if (appKey != null && appKey.isNotEmpty) {
        builder.element('AppKey', nest: appKey);
      }
      if (reqDigest != null && reqDigest.isNotEmpty) {
        builder.element('ReqDigest', nest: reqDigest);
      }
    });
    final loginXml = builder.buildDocument();
    return loginXml.toXmlString();
  }
}
