import 'dart:convert';

import 'package:xdja_bridge/gprs_server/protocol/base_protocol/base_response.dart';
import 'package:xml/xml.dart';

import 'login_fail_bean.dart';

const SESSION_ID = 'SessionID';
const POLICE_NO = 'PoliceNo';
const UNITS_CODING = 'UnitsCoding';
const MOBILE_NO = 'MobileNo';
const POWER = 'Power';
const MONTH3WPD = 'Month3Pwd';
const ID_CARD = 'IDCard';
const POLICE_ID = 'PoliceID';
const POLICE_NAME = 'PoliceName';
const UNIT_NAME = 'UnitName';
const DATE_TIME = 'DateTime';
const LIMITS = 'Limits';

/// 以下送检项目添加
const XJSSJH = 'Xjssjh';
const LAST_LOGIN_TIME = 'LastSuccLoginTime';
const LAST_LOGIN_SOURCE = 'LastLoginSource';
const LOGIN_SOURCE = 'LoginSource';
const LAST_LOGIN_FAIL_LOG = 'SuccAfterFailDesc';
const USNER_NAME_EXPIRE_DAYS = 'UserNameExpireDays';
const PWD_EXPIRE_DAYS = 'PwdExpireDays';

class LoginResponse with BaseResponse{
  LoginResponse();

  /// 会话id
  String sessionID;

  /// 警号
  String policeNo;

  /// 单位编码
  String unitsCoding;

  /// 手机号
  String moblieNo;

  /// 模块权限，以警号分隔
  String power;

  /// 密码
  String password;

  /// 服务器当前时间 yyyy-MM-dd HH:mm:ss
  String dateTime;

  /// 警员身份证号
  String idCard;

  /// 警员姓名
  String policeName;

  /// 警员id
  String policeID;

  /// 单位名称
  String unitName;

  /// 三个月份是否修改了密码
  bool month3Pwd;

  /// 应用权限
  String limits;

  /// 协警上级警号
  String auxiliaryPoliceLeader;

  /// 上次登录成功时间
  String lastLoginTime;

  /// 上次登录成功来源
  String lastLoginSource;

  /// 登录来源
  String loginSource;

  /// 上次登录失败情况
  List<LoginFailBean> lastLoginFailLog;

  /// 用户名到期天数
  String userNameExpireDays;

  /// 密码距离到期天数
  String pwdExpireDays;

  @override
  LoginResponse parseXml(String xmlData) {
    return LoginResponse.parseXml(xmlData);
  }

  factory LoginResponse.parseXml(String xmlData) {
    var loginResponse = LoginResponse();
    loginResponse.response = xmlData;
    final document = XmlDocument.parse(xmlData);
    var rootElement = document.getElement('Root');
    loginResponse.sessionID = rootElement.getElement(SESSION_ID)?.text;
    loginResponse.policeNo = rootElement.getElement(POLICE_NO)?.text;
    loginResponse.unitsCoding = rootElement.getElement(UNITS_CODING)?.text;
    loginResponse.moblieNo = rootElement.getElement(MOBILE_NO)?.text;
    loginResponse.power = rootElement.getElement(POWER)?.text;
    loginResponse.dateTime = rootElement.getElement(DATE_TIME)?.text;
    loginResponse.idCard = rootElement.getElement(ID_CARD)?.text;
    loginResponse.policeName = rootElement.getElement(POLICE_NAME)?.text;
    loginResponse.policeID = rootElement.getElement(POLICE_ID)?.text;
    loginResponse.unitName = rootElement.getElement(UNIT_NAME)?.text;
    loginResponse.month3Pwd = rootElement.getElement(MONTH3WPD)?.text == "0";
    loginResponse.limits = rootElement.getElement(LIMITS)?.text;

    loginResponse.auxiliaryPoliceLeader = rootElement.getElement(XJSSJH)?.text;
    loginResponse.lastLoginTime = rootElement.getElement(LAST_LOGIN_TIME)?.text;
    loginResponse.lastLoginSource =
        rootElement.getElement(LAST_LOGIN_SOURCE)?.text;
    loginResponse.loginSource = rootElement.getElement(LOGIN_SOURCE)?.text;
    if (rootElement.getElement(LAST_LOGIN_FAIL_LOG) != null &&
        rootElement.getElement(LAST_LOGIN_FAIL_LOG).text.isNotEmpty) {
      List<dynamic> map =
          jsonDecode(rootElement.getElement(LAST_LOGIN_FAIL_LOG)?.text);
      loginResponse.lastLoginFailLog = getLoginFailBeanList(map);
    }
    loginResponse.userNameExpireDays =
        rootElement.getElement(USNER_NAME_EXPIRE_DAYS)?.text;
    loginResponse.pwdExpireDays = rootElement.getElement(PWD_EXPIRE_DAYS)?.text;
    return loginResponse;
  }
}
