import 'package:xdja_bridge/gprs_server/protocol/base_protocol/base_response.dart';
import 'package:xml/xml.dart';

/// 查询返回协议

class QueryResponse with BaseResponse {
  QueryResponse();

  String response;

  /// 如果后台开启了综查单条返回详细信息，才会返回Rsdc节点
  bool rsdc = false;

  /// 请求类别
  String type;

  /// 数据项
  List<RowData> rowDataList;

  /// 关联查询节点
  List<Relation> relationList;

  /// 照片节点
  GetPhoto getPhoto;

  /// 分页信息
  PageInfo pageInfo;

    @override
  QueryResponse parseXml(String xmlData) {
    return QueryResponse.parseXml(xmlData);
  }

  factory QueryResponse.parseXml(String xmlData) {
    var queryResponse = QueryResponse();
    queryResponse.response = xmlData;
    final document = XmlDocument.parse(xmlData);
    var rootElement = document.getElement('RequestAgent');
    if (rootElement.getElement('Rsdc') != null) {
      queryResponse.rsdc = true;
    }
    queryResponse.type = rootElement.getElement('Type').text;
    var itemElement = rootElement.getElement('Items');
    var rowNodeList = itemElement?.getElement('Values')?.children;

    if (rowNodeList != null) {
      List<RowData> rowDataList = List();
      RowData rowData;
      List<String> keyList = List(rowNodeList.elementAt(0).children.length);
      //部分接口中文字段数量少于key字段，为防止出现中文字段与key字段数量不一致造成数组越界，统一使用key字段数量大小
      List<String> aliasList = List(rowNodeList.elementAt(0).children.length);
      for (int i = 0; i < rowNodeList.length; i++) {
        rowData = RowData();
        List<FieldData> fieldDataList = List();
        FieldData fieldData;
        var fieldNodeList = rowNodeList.elementAt(i).children;
        for (int j = 0; j < keyList.length; j++) {
          fieldData = FieldData();
          var fieldNode;
          if (i == 0) {
            fieldNode = fieldNodeList.elementAt(j);
            keyList[j] = fieldNode.text;
          } else if (i == 1) {
            //避免中文字段少于key字段长度导致越界
            if (j < rowNodeList.elementAt(1).children.length) {
              fieldNode = fieldNodeList.elementAt(j);
              aliasList[j] = fieldNode.text;
            } else {
              aliasList[j] = '';
            }
          } else {
            fieldNode = fieldNodeList.elementAt(j);
            fieldData.key = keyList[j];
            fieldData.alias = aliasList[j];
            fieldData.isCode = fieldNode.getAttribute('IsCode') == '1';
            fieldData.code = fieldNode.getAttribute('CodeValue');
            fieldData.value = fieldNode.text;
          }
          fieldDataList.add(fieldData);
        }
        rowData.fieldDataList = fieldDataList;
        if (i > 1) {
          rowDataList.add(rowData);
        }
      }
      queryResponse.rowDataList = rowDataList;
    }
    var relationNodeList = itemElement.getElement('Relation').children;
    if (relationNodeList != null) {
      List<Relation> relationList = List();
      Relation relation;
      for (var relationNode in relationNodeList) {
        relation = Relation();
        // 关联请求类别
        relation.sort = relationNode.getElement('Sort').text;
        // 中文名称
        relation.name = relationNode.getElement('Name').text;
        // 关联查询条件
        relation.condition = relationNode.getElement('Condition').text;
        // 关联业务数据源
        relation.dbSource = relationNode.getElement('DbSource').text;
        relation.isXml = relationNode.getElement('IsXml')?.text == '1';
        relation.alert = relationNode.getElement('Alert')?.text;
        //节点数大于4为报警节点
        relation.isAlert = relationNode.children.length > 4;
        relationList.add(relation);
      }
      queryResponse.relationList = relationList;
    }
    var getPhotoElement = itemElement.getElement('GetPhoto');
    if (getPhotoElement != null) {
      var getPhoto = GetPhoto();
      getPhoto.reqType = getPhotoElement.getElement('ReqType').text;
      getPhoto.reqTable = getPhotoElement.getElement('ReqTable').text;
      getPhoto.condition = getPhotoElement.getElement('Condition').text;
      getPhoto.dbSource = getPhotoElement.getElement('DbSource').text;
      getPhoto.fieldList = getPhotoElement.getElement('FieldList').text;
      queryResponse.getPhoto = getPhoto;
    }
    var pageElement = itemElement.getElement('Page');
    if (pageElement != null) {
      var page = PageInfo();
      page.size = int.parse(pageElement.getElement('Size').text);
      page.totalLen = int.parse(pageElement.getElement('TotalLen').text);
      page.currentLen = int.parse(pageElement.getElement('CurrentLen').text);
      page.totalPage = int.parse(pageElement.getElement('TotalPage').text);
      page.beginNo = int.parse(pageElement.getElement('BeginNo').text);
      page.sourceCondition = pageElement.getElement('SourceCondition').text;
      page.sourceDbSource = pageElement.getElement('SourceDbSource').text;
      queryResponse.pageInfo = page;
    }
    return queryResponse;
  }
}

/// 对应一条查询结果，每一条数据包含了一个FieldData数据list
///
/// 每一个FieldData包含一个字段的key、alias、code、value
class RowData {
  /// 字段list
  List<FieldData> fieldDataList;

  /// 根据某字段key获取该字段字典值
  ///[key] 字段key
  String getFieldCodeByKey(String key) {
    return _getField(key, ENUMFIELDDATA.CODE);
  }

  /// 根据耨字段key获取该字段值
  ///  [key] 字段key
  String getFieldValueByKey(String key) {
    return _getField(key, ENUMFIELDDATA.VALUE);
  }

  /// 根据某字段key获取该字段中文名称
  /// [key] 字段key
  /// return 字段中文名称（别名）
  String getFieldAliasByKey(String key) {
    return _getField(key, ENUMFIELDDATA.ALIAS);
  }

  /// 根据字段key获取该字段所有数据
  ///  [key] 字段key

  FieldData getFieldByKey(String key) {
    FieldData defaultFieldData;
    if (key == null ||
        key.isEmpty ||
        fieldDataList == null ||
        fieldDataList.isEmpty) {
      return null;
    }
    for (var fieldData in fieldDataList) {
      if (fieldData.key == key) {
        defaultFieldData = fieldData;
        break;
      }
    }

    return defaultFieldData;
  }

  String _getField(String key, ENUMFIELDDATA item) {
    String defaultStr = "";
    if (key == null ||
        key.isEmpty ||
        fieldDataList == null ||
        fieldDataList.isEmpty) {
      return defaultStr;
    }

    if (item == ENUMFIELDDATA.CODE) {
      for (var fieldData in fieldDataList) {
        if (key == fieldData.key) {
          defaultStr = fieldData.code;
          break;
        }
      }
    } else if (item == ENUMFIELDDATA.ALIAS) {
      for (var fieldData in fieldDataList) {
        if (key == fieldData.key) {
          defaultStr = fieldData.alias;
          break;
        }
      }
    } else if (item == ENUMFIELDDATA.VALUE) {
      for (var fieldData in fieldDataList) {
        if (key == fieldData.key) {
          defaultStr = fieldData.value;
          break;
        }
      }
    }
    return defaultStr;
  }
}

enum ENUMFIELDDATA { ALIAS, VALUE, CODE }

/// 一个字段对应的数据
class FieldData {
  /// 字段key，例如：c_xb
  String key;

  /// 字段别名，例如：性别
  String alias;

  /// 字段值，例如：男
  String value;

  /// 是否翻译
  bool isCode;

  /// 字段属性 例如：1（此字段一般只有有对应的有字典翻译时才有值，value对用中文翻译，code对应字典代码）
  String code;
}

/// 照片节点
class GetPhoto {
  /// 请求类别
  String reqType;

  /// 照片所在的表
  String reqTable;

  /// 查询条件
  String condition;

  /// 当前照片数据源
  String dbSource;

  /// 照片字段
  String fieldList;
}

///  关联查询节点
class Relation {
  /// 关联请求类别
  String sort;

  /// 对应中文名称
  String name;

  /// 关联查询条件
  String condition;

  /// 关联业务对应数据源
  String dbSource;

  /// Alert节点是否包含xml
  bool isXml;

  /// 报警信息
  String alert;

  /// 是否报警
  bool isAlert;
}

/// 分页信息
class PageInfo {
  /// 分页大小
  int size;

  /// 总记录数
  int totalLen;

  /// 当前页记录数
  int currentLen;

  /// 起始记录数
  int beginNo;

  /// 总页数
  int totalPage;

  ///  原始查询条件
  String sourceCondition;

  /// 原始数据源
  String sourceDbSource;
}
