/// 登录方式
class LoginTypeExtension {
  /// 警号登录方式
  static const String policeNoType = "0";

  /// 身份证号登录方式
  static const String idcardType = "1";

  /// 手机号登录方式
  static const String moblieType = "2";

  /// 票据登录方式
  static const String billType = "3";
}

/// 录入协议中存在同时操作多个表时是否是主表扩展
/// 录入协议中可存在多个表，但是只能有一个表示主表
class IsMainExtension {
  /// 主表
  static const String isMain = "1";

  /// 非主表
  static const String notMain = "0";
}

class OperateExtension {
  /// 插入操作，用于新增数据
  static const String insert = "insert";

  /// 更新操作，用于更新已有数据
  /// condition条件不能为空
  static const String update = "update";

  /// 删除操作，用于删除数据
  /// condition条件不能为空
  static const String delete = "delete";
}

/// 查询字段Relation属性，逻辑关系扩展（区分大小写）
/// 包含数字表示和字符表示两种方式，不区分大小写
/// 考虑到字符表示形式容易记忆，建议传递字符表示
/// 默认值 1或EQ
///
/// 规则：
/// 当Relation为8、12或IN、NI时，多个值中间使用英文逗号进行分割，值两边不需要 添加任何单引号或双引号。
///
/// 当Relation为5、6、7、11或RL、LL、AL、NL时,终端不用在值上追加%,后台系统会自动添加
///
/// 当Relation为14或CR时字符替换，根据后台配置文件中的配置，将查询值中的字符践行替换
/// 如配置为【*，%】，查询内容【张*三】，则替换为【张%三】
class RelationNumberExpression {
  /// 等于 =关系（默认值）
  static const String equal = "1";

  ///  != 或 <>
  static const String notEqual = "2";

  /// 大于等于 >=
  static const String greatEqual = "3";

  /// 小于等于 <=
  static const String lessEqual = "4";

  /// 右like，终端不用在值上追加%，后台系统会自动添加
  static const String rightLike = "5";

  /// 左like，终端不用在值上追加%，后台系统会自动添加
  static const String leftLike = "6";

  /// 全like，终端不用在值上追加%，后台系统会自动添加
  static const String allLike = "7";

  /// in，多个值中间使用英文逗号进行分割，值两边不需要添加任何单引号或者双引号
  static const String relationIn = "8";

  /// 大于 >
  static const String grealThan = "9";

  /// 小于 <
  static const String lessThan = "10";

  ///  not like(DRS 2.0支持)，终端不用在值上追加%，后台系统会自动添加
  static const String notLike = "11";

  /// not in(DRS 2.0支持) 多个值中间使用英文逗号进行分割，值两边不需要添加任何单引号或者双引号
  static const String notIn = "12";

  /// between (DRS 2.0支持)
  static const String between = "13";

  /// like 字符替换，根据后台配置文件中的配置，将查询值中的字符践行替换
  /// 如配置为【*，%】，查询内容【张*三】，则替换为【张%三】
  static const String like = "14";
}

class RelationCharExpression {
  /// 等于 =关系（默认值）
  static const String equal = "EQ";

  /// != 或 <>
  static const String notEqual = "NE";

  /// 大于等于 >=
  static const String greatEqual = "GE";

  /// 小于等于 <=
  static const String lessEqual = "LE";

  /// 右like，终端不用在值上追加%，后台系统会自动添加
  static const String rightLike = "RL";

  /// 左like，终端不用在值上追加%，后台系统会自动添加
  static const String leftLike = "LL";

  /// 全like，终端不用在值上追加%，后台系统会自动添加
  static const String allLike = "AI";

  /// in，多个值中间使用英文逗号进行分割，值两边不需要添加任何单引号或者双引号
  static const String relationIn = "IN";

  /// 大于 >
  static const String greatThan = "GT";

  /// 小于 <
  static const String lessThan = "LT";

  /// not like(DRS 2.0支持)，终端不用在值上追加%，后台系统会自动添加
  static const String notLike = "NL";

  ///  not in(DRS 2.0支持)，多个值中间使用英文逗号进行分割，值两边不需要添加任何单引号或者双引号
  static const String notIn = "NI";

  ///  between (DRS 2.0支持)
  static const String between = "BT";

  /// like 字符替换，根据后台配置文件中的配置，将查询值中的字符践行替换
  /// 如配置为【*，%】，查询内容【张*三】，则替换为【张%三】
  static const String like = "CR";
}

/// 查询字段Type属性，数据类型扩展（区分大小写）
/// 包含数字表示和字符表示两种方式，不区分大小写
/// 考虑到字符表示形式容易记忆，建议传递字符表示
/// 默认值 1或char
class TypeNumberExpression {
  /// 字符型（默认值）
  static const String charType = "1";

  /// 数字型
  static const String numberType = "2";

  /// 日期型，要保证日期的有效性，否则系统将抛出错误给终端
  static const String dateType = "3";

  /// 值转为拼音
  static const String v2pType = "4";
}

/// 字符表示
class TypeCharExpression {
  /// 字符型（默认值）
  static const String charType = "Char";

  /// 数字型
  static const String numberType = "Number";

  /// 日期型，要保证日期的有效性，否则系统将抛出错误给终端
  static const String dateType = "Date";

  /// 值转为拼音
  static const String v2pType = "v2p";
}

/// 查询字段SplitJoint属性，与前一个条件的拼接关系扩展（区分大小写）
/// 包含数字表示和字符表示两种方式，不区分大小写
/// 考虑到字符表示形式容易记忆，建议传递字符表示
/// 不写SplitJoint属性时，默认各字段间关系为and
/// 默认值 1或and
class SplitJointNumberExpression {
  /// and关系（默认值）
  static const String and = "1";

  /// or关系
  static const String or = "2";
}

class SplitJointcharExpression {
  /// and关系（默认值）
  static const String and = "and";

  /// or关系
  static const String or = "or";
}
